@@ -1,9 +1,19 @@
-import six
+import tomlkit
 
-from .base import DataView
+from .base import DataModel, DataValidationError
+
+class PackageSpecfiers(DataModel):
+    # TODO: one could add here more validation for path editable
+    # and more stuff which is currently allowed and undocumented
+    __SCHEMA__ = {}
+    __OPTIONAL__ = {
+        "editable": bool,
+        "version": str,
+        "extras": list
+    }
 
 
-class Package(DataView):
+class Package(DataModel):
     """A package requirement specified in a Pipfile.
 
     This is the base class of variants appearing in either `[packages]` or
@@ -13,20 +23,21 @@ class Package(DataView):
     # to have oneof_schema (at least I can't do it), so we wrap this in a
     # top-level key. The Requirement model class implements extra hacks to
     # make this work.
-    __SCHEMA__ = {
-        "__package__": {
-            "oneof_type": ["string", "dict"],
-        },
+    __OPTIONAL__ = {
+        "PackageSpecfiers":  (str, dict)
     }
 
     @classmethod
     def validate(cls, data):
-        # HACK: Make this validatable for Cerberus. See comments in validation
-        # side for more information.
-        return super(Package, cls).validate({"__package__": data})
+        if isinstance(data, (str, tomlkit.items.Float, tomlkit.items.Integer)):
+            return
+        if isinstance(data, dict):
+            PackageSpecfiers.validate(data)
+        else:
+            raise DataValidationError(f"invalid type for package data: {type(data)}")
 
     def __getattr__(self, key):
-        if isinstance(self._data, six.string_types):
+        if isinstance(self._data, (str, tomlkit.items.Float, tomlkit.items.Integer)):
             if key == "version":
                 return self._data
             raise AttributeError(key)
@@ -38,8 +49,8 @@ class Package(DataView):
 
     def __setattr__(self, key, value):
         if key == "_data":
-            super(Package, self).__setattr__(key, value)
-        elif key == "version" and isinstance(self._data, six.string_types):
+            super().__setattr__(key, value)
+        elif key == "version" and isinstance(self._data, str):
             self._data = value
         else:
             self._data[key] = value
